git.delta.rocks / unique-network / refs/commits / 706a25703b77

difftreelog

test regenerate .sol for refungible

Yaroslav Bolyukin2023-01-12parent: #0f0494d.patch.diff
in: master

4 files changed

modifiedpallets/refungible/src/stubs/UniqueRefungible.rawdiffbeforeafterboth

binary blob — no preview

modifiedpallets/refungible/src/stubs/UniqueRefungible.soldiffbeforeafterboth
641 TransferEnabled641 TransferEnabled
642}642}
643643
644/// @title ERC-721 Non-Fungible Token Standard, optional metadata extension
645/// @dev See https://eips.ethereum.org/EIPS/eip-721
644/// @dev the ERC-165 identifier for this interface is 0x5b5e139f646/// @dev the ERC-165 identifier for this interface is 0x5b5e139f
645contract ERC721Metadata is Dummy, ERC165 {647contract ERC721Metadata is Dummy, ERC165 {
646 // /// @notice A descriptive name for a collection of NFTs in this contract648 // /// @notice A descriptive name for a collection of NFTs in this contract
783}785}
784786
785/// @title Unique extensions for ERC721.787/// @title Unique extensions for ERC721.
786/// @dev the ERC-165 identifier for this interface is 0xabf30dc2788/// @dev the ERC-165 identifier for this interface is 0xb365c124
787contract ERC721UniqueExtensions is Dummy, ERC165 {789contract ERC721UniqueExtensions is Dummy, ERC165 {
788 /// @notice A descriptive name for a collection of NFTs in this contract790 /// @notice A descriptive name for a collection of NFTs in this contract
789 /// @dev EVM selector for this function is: 0x06fdde03,791 /// @dev EVM selector for this function is: 0x06fdde03,
986 return 0x0000000000000000000000000000000000000000;988 return 0x0000000000000000000000000000000000000000;
987 }989 }
990
991 /// @notice Returns collection helper contract address
992 /// @dev EVM selector for this function is: 0x1896cce6,
993 /// or in textual repr: collectionHelperAddress()
994 function collectionHelperAddress() public view returns (address) {
995 require(false, stub_error);
996 dummy;
997 return 0x0000000000000000000000000000000000000000;
998 }
988}999}
9891000
990/// @dev anonymous struct1001/// @dev anonymous struct
10421053
1043/// @title ERC-721 Non-Fungible Token Standard1054/// @title ERC-721 Non-Fungible Token Standard
1044/// @dev See https://github.com/ethereum/EIPs/blob/master/EIPS/eip-721.md1055/// @dev See https://github.com/ethereum/EIPs/blob/master/EIPS/eip-721.md
1045/// @dev the ERC-165 identifier for this interface is 0x4016cd871056/// @dev the ERC-165 identifier for this interface is 0x80ac58cd
1046contract ERC721 is Dummy, ERC165, ERC721Events {1057contract ERC721 is Dummy, ERC165, ERC721Events {
1047 /// @notice Count all RFTs assigned to an owner1058 /// @notice Count all RFTs assigned to an owner
1048 /// @dev RFTs assigned to the zero address are considered invalid, and this1059 /// @dev RFTs assigned to the zero address are considered invalid, and this
1075 }1086 }
10761087
1077 /// @dev Not implemented1088 /// @dev Not implemented
1078 /// @dev EVM selector for this function is: 0x60a11672,1089 /// @dev EVM selector for this function is: 0xb88d4fde,
1079 /// or in textual repr: safeTransferFromWithData(address,address,uint256,bytes)1090 /// or in textual repr: safeTransferFrom(address,address,uint256,bytes)
1080 function safeTransferFromWithData(1091 function safeTransferFrom(
1081 address from,1092 address from,
1082 address to,1093 address to,
1083 uint256 tokenId,1094 uint256 tokenId,
1174 return false;1185 return false;
1175 }1186 }
1176
1177 /// @notice Returns collection helper contract address
1178 /// @dev EVM selector for this function is: 0x1896cce6,
1179 /// or in textual repr: collectionHelperAddress()
1180 function collectionHelperAddress() public view returns (address) {
1181 require(false, stub_error);
1182 dummy;
1183 return 0x0000000000000000000000000000000000000000;
1184 }
1185}1187}
11861188
1187contract UniqueRefungible is1189contract UniqueRefungible is
modifiedtests/src/eth/abi/reFungible.jsondiffbeforeafterboth
--- a/tests/src/eth/abi/reFungible.json
+++ b/tests/src/eth/abi/reFungible.json
@@ -616,7 +616,7 @@
       { "internalType": "uint256", "name": "tokenId", "type": "uint256" },
       { "internalType": "bytes", "name": "data", "type": "bytes" }
     ],
-    "name": "safeTransferFromWithData",
+    "name": "safeTransferFrom",
     "outputs": [],
     "stateMutability": "nonpayable",
     "type": "function"
modifiedtests/src/eth/api/UniqueRefungible.soldiffbeforeafterboth
--- a/tests/src/eth/api/UniqueRefungible.sol
+++ b/tests/src/eth/api/UniqueRefungible.sol
@@ -441,6 +441,8 @@
 	TransferEnabled
 }
 
+/// @title ERC-721 Non-Fungible Token Standard, optional metadata extension
+/// @dev See https://eips.ethereum.org/EIPS/eip-721
 /// @dev the ERC-165 identifier for this interface is 0x5b5e139f
 interface ERC721Metadata is Dummy, ERC165 {
 	// /// @notice A descriptive name for a collection of NFTs in this contract
@@ -534,7 +536,7 @@
 }
 
 /// @title Unique extensions for ERC721.
-/// @dev the ERC-165 identifier for this interface is 0xabf30dc2
+/// @dev the ERC-165 identifier for this interface is 0xb365c124
 interface ERC721UniqueExtensions is Dummy, ERC165 {
 	/// @notice A descriptive name for a collection of NFTs in this contract
 	/// @dev EVM selector for this function is: 0x06fdde03,
@@ -660,6 +662,11 @@
 	/// @dev EVM selector for this function is: 0xab76fac6,
 	///  or in textual repr: tokenContractAddress(uint256)
 	function tokenContractAddress(uint256 token) external view returns (address);
+
+	/// @notice Returns collection helper contract address
+	/// @dev EVM selector for this function is: 0x1896cce6,
+	///  or in textual repr: collectionHelperAddress()
+	function collectionHelperAddress() external view returns (address);
 }
 
 /// @dev anonymous struct
@@ -702,7 +709,7 @@
 
 /// @title ERC-721 Non-Fungible Token Standard
 /// @dev See https://github.com/ethereum/EIPs/blob/master/EIPS/eip-721.md
-/// @dev the ERC-165 identifier for this interface is 0x4016cd87
+/// @dev the ERC-165 identifier for this interface is 0x80ac58cd
 interface ERC721 is Dummy, ERC165, ERC721Events {
 	/// @notice Count all RFTs assigned to an owner
 	/// @dev RFTs assigned to the zero address are considered invalid, and this
@@ -725,9 +732,9 @@
 	function ownerOf(uint256 tokenId) external view returns (address);
 
 	/// @dev Not implemented
-	/// @dev EVM selector for this function is: 0x60a11672,
-	///  or in textual repr: safeTransferFromWithData(address,address,uint256,bytes)
-	function safeTransferFromWithData(
+	/// @dev EVM selector for this function is: 0xb88d4fde,
+	///  or in textual repr: safeTransferFrom(address,address,uint256,bytes)
+	function safeTransferFrom(
 		address from,
 		address to,
 		uint256 tokenId,
@@ -783,11 +790,6 @@
 	/// @dev EVM selector for this function is: 0xe985e9c5,
 	///  or in textual repr: isApprovedForAll(address,address)
 	function isApprovedForAll(address owner, address operator) external view returns (bool);
-
-	/// @notice Returns collection helper contract address
-	/// @dev EVM selector for this function is: 0x1896cce6,
-	///  or in textual repr: collectionHelperAddress()
-	function collectionHelperAddress() external view returns (address);
 }
 
 interface UniqueRefungible is